==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultPreviewPanel__24PreviewBorder.h <==
// class javax.swing.colorchooser.DefaultPreviewPanel$PreviewBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 44eb3e54ec164aaf javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder_H_
#define _JC_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_refs	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$refs	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$nonrefs	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object;

typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$fields_struct	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vmethods	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtable	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtype	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$fields_struct {
	jint	edge;
	jint	gap;
	jint	lead;
};
extern _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$fields_struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method$_init$fa3ef3a60c6ee9ae(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *, struct _jc_java_awt_Component$object *);
extern jboolean _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *);
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *, struct _jc_java_awt_Component$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vmethods	javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$refs {
    _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_refs	javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_nonrefs	javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object {
	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtype _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder_H_ */

==> jc-1.4.6.tar.gz: javax/swing/colorchooser/DefaultPreviewPanel__24PreviewBorder.h <==
// class javax.swing.colorchooser.DefaultPreviewPanel$PreviewBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 44eb3e54ec164aaf javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder_H_
#define _JC_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_refs	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$refs	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$nonrefs	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object;

typedef struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$fields_struct	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$fields_struct;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vmethods	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtable	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtype	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtype;

// Class fields structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$fields_struct {
	jint	edge;
	jint	gap;
	jint	lead;
};
extern _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$fields_struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$class_fields;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method$_init$fa3ef3a60c6ee9ae(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vmethods	javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultPreviewPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$refs {
    _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_refs	javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$sub_nonrefs	javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$object {
	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$vtype _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultPreviewPanel__24PreviewBorder_H_ */
